/*!
    MIT License

    https://github.com/jonathandann/blink
    Copyright (c) 2019 Jonathan Dann

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
*/
export declare class AccessToken {
    readonly token: string;
    readonly expiration: Date;
    constructor(token: string, expiration: Date);
}
export interface Device {
    identifier: string;
    name: string;
}
export declare class Panel implements Device {
    readonly identifier: string;
    readonly name: string;
    readonly state: Panel.State;
    constructor(identifier: string, name: string, state: Panel.State);
}
export declare namespace Panel {
    const enum State {
        Armed = "arm",
        Home = "home",
        Disarmed = "disarm"
    }
}
export declare class ContactSensor implements Device {
    readonly identifier: string;
    readonly name: string;
    readonly state: ContactSensor.State;
    constructor(identifier: string, name: string, state: ContactSensor.State);
}
export declare namespace ContactSensor {
    enum State {
        Closed = 0,
        Open = 1
    }
}
export declare class MotionSensor implements Device {
    readonly identifier: string;
    readonly name: string;
    readonly state: MotionSensor.State;
    constructor(identifier: string, name: string, state: MotionSensor.State);
}
export declare namespace MotionSensor {
    enum State {
        None = 0,
        Triggered = 1
    }
}
export declare type Sensor = ContactSensor | MotionSensor;
