/*!
    MIT License

    https://github.com/jonathandann/yalesyncalarm
    Copyright (c) 2019 Jonathan Dann

    Forked from https://github.com/jonathan-fielding/yalealarmsystem
    Copyright 2019 Jonathan Fielding, Jack Mellor & Adam Green

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
*/
import { AccessToken, ContactSensor, Panel, MotionSensor } from './Model';
import { ILogger } from './Logger';
export declare function getMode(accessToken: AccessToken): Promise<Panel.State>;
export declare type ContactSensors = {
    [key: string]: ContactSensor;
};
export declare type MotionSensors = {
    [key: string]: MotionSensor;
};
export declare class Yale {
    private readonly _username;
    private readonly _password;
    private readonly _log;
    private _panel?;
    private _contactSensors;
    private _motionSensors;
    private _lock;
    constructor(_username: string, _password: string, _log?: ILogger);
    private _updatePanel;
    private _updateSensors;
    update(): Promise<void>;
    panel(): Promise<Panel | undefined>;
    motionSensors(): Promise<MotionSensors>;
    contactSensors(): Promise<ContactSensors>;
    getPanelState(): Promise<Panel.State>;
    setPanelState(targetState: Panel.State): Promise<Panel.State>;
    updateMotionSensor(sensor: MotionSensor): Promise<MotionSensor | undefined>;
    updateContactSensor(sensor: ContactSensor): Promise<ContactSensor | undefined>;
}
